==> fet_3.12.30.orig.tar.gz: fet-3.12.30/src/interface/addconstraintminndaysbetweenactivitiesform.h <==
/***************************************************************************
                          addconstraintminndaysbetweenactivitiesform.h  -  description
                             -------------------
    begin                : Feb 11, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : liviu@lalescu.ro
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTMINNDAYSBETWEENACTIVITIESFORM_H
#define ADDCONSTRAINTMINNDAYSBETWEENACTIVITIESFORM_H

#include "addconstraintminndaysbetweenactivitiesform_template.h"
#include "genetictimetable_defs.h"
#include "genetictimetable.h"
#include "fet.h"
#include "fetmainform.h"

#include <qcombobox.h>
#include <qlistbox.h>
#include <qmessagebox.h>
#include <qgroupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qtextedit.h>
#include <qvaluelist.h>

class AddConstraintMinNDaysBetweenActivitiesForm : public AddConstraintMinNDaysBetweenActivitiesForm_template  {
public:
	AddConstraintMinNDaysBetweenActivitiesForm();
	~AddConstraintMinNDaysBetweenActivitiesForm();

	void updateActivitiesListBox();
	
	void addActivity();
	void removeActivity();

	void addConstraint();
	
private:
	//the id's of the activities listed in the activities list
	QValueList<int> activitiesList;
	//the id-s of the activities listed in the list of selected activities
	QValueList<int> selectedActivitiesList;
};

#endif

==> fet_3.18.2.orig.tar.gz: fet-3.18.2/src/interface/addconstraintminndaysbetweenactivitiesform.h <==
/***************************************************************************
                          addconstraintminndaysbetweenactivitiesform.h  -  description
                             -------------------
    begin                : Feb 11, 2005
    copyright            : (C) 2005 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef ADDCONSTRAINTMINNDAYSBETWEENACTIVITIESFORM_H
#define ADDCONSTRAINTMINNDAYSBETWEENACTIVITIESFORM_H

#include "addconstraintminndaysbetweenactivitiesform_template.h"
#include "genetictimetable_defs.h"
#include "genetictimetable.h"
#include "fet.h"
#include "fetmainform.h"

#include <qcombobox.h>
#include <qlistbox.h>
#include <qmessagebox.h>
#include <qgroupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <qtextedit.h>
#include <qvaluelist.h>

class AddConstraintMinNDaysBetweenActivitiesForm : public AddConstraintMinNDaysBetweenActivitiesForm_template  {
public:
	AddConstraintMinNDaysBetweenActivitiesForm();
	~AddConstraintMinNDaysBetweenActivitiesForm();

	void updateActivitiesListBox();
	
	void addActivity();
	void removeActivity();

	void addConstraint();
	
private:
	//the id's of the activities listed in the activities list
	QValueList<int> activitiesList;
	//the id-s of the activities listed in the list of selected activities
	QValueList<int> selectedActivitiesList;
};

#endif
